pub enum ScanOutcome {
Found(Box<DaemonInfo>),
FreePort(u16),
AllOccupied,
}Expand description
The outcome of scanning a port range for a running daemon or a free port to spawn on.
Variants
Found(Box<DaemonInfo>)
Found a running hyperdb-mcp daemon.
FreePort(u16)
No daemon found, but this port is free (can spawn here).
AllOccupied
All ports in the range are occupied (either by our daemon, foreign services, or both).