pub fn write_discovery_file(info: &DaemonInfo) -> Result<()>Expand description
Write the discovery file atomically (write-to-temp then rename).
Errors
Returns an error if the state directory cannot be created or the file cannot be written.
pub fn write_discovery_file(info: &DaemonInfo) -> Result<()>Write the discovery file atomically (write-to-temp then rename).
Returns an error if the state directory cannot be created or the file cannot be written.