client_should_take_over

Function client_should_take_over 

pub fn client_should_take_over(client_ver: &str, daemon_ver: &str) -> bool
Pure version comparison: returns true if the client should take over the daemon. Only returns true when both versions parse successfully AND client > daemon. Unparseable versions or equal/older client always return false (reuse daemon).