pub fn ensure_daemon(port: u16) -> Result<DaemonInfo>Expand description
Ensure a daemon is running and return its info. If no daemon is detected, spawn one and wait for it to become ready.
Errors
Returns an error if the daemon cannot be spawned or does not become ready within the timeout period.